@@ -11,13 +11,13 @@
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QScreen>
-#include <QSortFilterProxyModel>
 
 using namespace KDevelop;
 
-AsyncTreeView::AsyncTreeView(TreeModel* model, QSortFilterProxyModel *proxy, QWidget *parent = nullptr)
+AsyncTreeView::AsyncTreeView(TreeModel& treeModel, QWidget* parent)
     : QTreeView(parent)
-    , m_proxy(proxy)
+    , m_treeModel(treeModel)
+    , m_autoResizeColumns(true)
 {
     connect (this, &AsyncTreeView::expanded,
              this, &AsyncTreeView::slotExpanded);
@@ -25,26 +25,25 @@ AsyncTreeView::AsyncTreeView(TreeModel* model, QSortFilterProxyModel *proxy, QWi
              this, &AsyncTreeView::slotCollapsed);
     connect (this, &AsyncTreeView::clicked,
              this, &AsyncTreeView::slotClicked);
-    connect (model, &TreeModel::itemChildrenReady,
-            this, &AsyncTreeView::slotExpandedDataReady);
+    connect(&m_treeModel, &TreeModel::itemChildrenReady, this, &AsyncTreeView::slotExpandedDataReady);
 }
 
 
 void AsyncTreeView::slotExpanded(const QModelIndex &index)
 {
-    static_cast<TreeModel*>(model())->expanded(m_proxy->mapToSource(index));
+    m_treeModel.expanded(mapViewIndexToTreeModelIndex(index));
 }
 
 void AsyncTreeView::slotCollapsed(const QModelIndex &index)
 {
-    static_cast<TreeModel*>(model())->collapsed(m_proxy->mapToSource(index));
-    resizeColumns();
+    m_treeModel.collapsed(mapViewIndexToTreeModelIndex(index));
+    resizeColumnsAutomatically();
 }
 
 void AsyncTreeView::slotClicked(const QModelIndex &index)
 {
-    static_cast<TreeModel*>(model())->clicked(m_proxy->mapToSource(index));
-    resizeColumns();
+    m_treeModel.clicked(mapViewIndexToTreeModelIndex(index));
+    resizeColumnsAutomatically();
 }
 
 QSize AsyncTreeView::sizeHint() const
@@ -67,8 +66,30 @@ void AsyncTreeView::resizeColumns()
     this->updateGeometry();
 }
 
-void AsyncTreeView::slotExpandedDataReady()
+void AsyncTreeView::setAutoResizeColumns(bool on)
 {
-    resizeColumns();
+    m_autoResizeColumns = on;
+    resizeColumnsAutomatically();
 }
 
+TreeModel& AsyncTreeView::treeModel()
+{
+    return m_treeModel;
+}
+
+void AsyncTreeView::slotExpandedDataReady()
+{
+    resizeColumnsAutomatically();
+}
+
+QModelIndex AsyncTreeView::mapViewIndexToTreeModelIndex(const QModelIndex& viewIndex) const
+{
+    return viewIndex;
+}
+
+void AsyncTreeView::resizeColumnsAutomatically()
+{
+    if (m_autoResizeColumns) {
+        resizeColumns();
+    }
+}
