@@ -11,6 +11,8 @@
 
 #include <language/duchain/stringhelpers.h>
 
+#include <cstring>
+
 QTEST_MAIN(TestStringHelpers)
 
 using namespace KDevelop;
@@ -133,22 +135,35 @@ void TestStringHelpers::testParamIterator_data()
     QTest::addColumn<QString>("parens");
     QTest::addColumn<QString>("source");
     QTest::addColumn<QStringList>("params");
+    QTest::addColumn<int>("endPosition");
 
-    auto addTest = [](const QString& source, const QStringList& params) {
-        QTest::addRow("%s", qPrintable(source)) << QStringLiteral("<>:") << source << params;
+    auto addGeneralTest = [](const QString& parens, const QString& source, const QStringList& params,
+                             int endPosition = -1) {
+        QTest::addRow("%s", qPrintable(source))
+            << parens << source << params << (endPosition == -1 ? source.size() : endPosition);
     };
-    auto addMacroTest = [](const QString& source, const QStringList& params) {
-        QTest::addRow("%s", qPrintable(source)) << QStringLiteral("()") << source << params;
+    auto addTest = [addGeneralTest](const QString& source, const QStringList& params, int endPosition = -1) {
+        addGeneralTest("<>:", source, params, endPosition);
+    };
+    auto addMacroTest = [addGeneralTest](const QString& source, const QStringList& params, int endPosition = -1) {
+        addGeneralTest("()", source, params, endPosition);
     };
 
     addTest("Empty", {});
     addTest("Foo<T1, T2>", {"T1", "T2"});
     addTest("operator<", {});
 
-    // These are valid C++ snippets, but I couldn't make such strings be passed to ParamIterator in practice.
+    // Such strings are passed to ParamIterator() when an Identifier is constructed from a template argument inside the
+    // call to Visitor::makeType() in Visitor::createClassTemplateSpecializationType(). For example, the following valid
+    // C++ code `K< &operator<< <S> > k;` passes the string "&operator<<<S>" to ParamIterator().
     addTest("operator< <QString>", {"QString"});
     addTest("operator<<<KDevVarLengthArray, Path >", {"KDevVarLengthArray", "Path"});
     addTest("operator<=>< QRegularExpression,IndexedString*,char\t>", {"QRegularExpression", "IndexedString*", "char"});
+    // The valid C++ code `C<decltype(A::f<int>)> c;` passes the string "decltype(A::f<int>)" to ParamIterator().
+    addTest("decltype(f<int>)", {});
+    addTest("decltype(A::f)", {});
+    addTest("decltype(A::f<int>)", {});
+    addTest("decltype(N::operator<  <N::String>)", {});
 
     addTest("__not_overloaded2<_Tp, foo<bar>, __void_t<decltype(std::declval<_Tp>().operator<(std::declval<_Up>()))>>",
             {"_Tp", "foo<bar>", "__void_t<decltype(std::declval<_Tp>().operator<(std::declval<_Up>()))>"});
@@ -181,10 +196,17 @@ void TestStringHelpers::testParamIterator_data()
     addTest("Y<decltype(&X::operator<=), Z<&X::operator<=>>", {"decltype(&X::operator<=)", "Z<&X::operator<=>"});
     // c++20 operator<=>
     addTest("Y<decltype(&X::operator<=>), Z<&X::operator<=>>>", {"decltype(&X::operator<=>)", "Z<&X::operator<=>>"});
-    // NOTE: this identifier here is invalid but we shouldn't trigger UB either, so the test is just that we get _something_ (even if it's wrong)
-    addTest("bogus<_Tp, _Up, invalid<decltype(<=(std::declval<_Tp>(), std::declval<_Up>()))>>", {"_Tp", "_Up", "invalid<decltype(<=(std::declval<_Tp>(), std::declval<_Up>()))>>"});
+    // NOTE: the "bogus" identifiers below are invalid but shouldn't trigger UB, so the tests verify that we get
+    // _something_ (even if it's wrong).
+    addTest("bogus<_Tp, _Up, invalid<decltype(<=(std::declval<_Tp>(), std::declval<_Up>()))>>",
+            {"_Tp", "_Up", "invalid<decltype(<=(std::declval<_Tp>(), std::declval<_Up>()))>"});
+    addTest("bogus<_Tp, _Up, invalid<<=(std::declval<_Tp>(), std::declval<_Up>())>>",
+            {"_Tp", "_Up", "invalid<<=(std::declval<_Tp>(), std::declval<_Up>())>>"});
     addTest("hardToParse<A<B>", {"A<B"});
+    addTest("hardToParse<(A<B)>", {"(A<B)"});
     addTest("hardToParse<(A>B)>", {"(A>B)"});
+    addTest("hardToParse<Foo<(A<B)>>", {"Foo<(A<B)>"});
+    addTest("hardToParse<Foo<(A>B)>>", {"Foo<(A>B)>"});
 
     // Such zero/empty tparam strings are actually passed to ParamIterator() while libstdc++ headers are parsed.
     addTest("_Index_tuple<>", {});
@@ -193,8 +215,34 @@ void TestStringHelpers::testParamIterator_data()
     addTest("__hash_enum<_Tp,\t  \t>", {"_Tp", ""});
     addTest("__uniq_ptr_data<_Tp, _Dp, , >", {"_Tp", "_Dp", "", ""});
 
-    addMacroTest("Q_UNIMPLEMENTED() qWarning(\"Unimplemented code.\")", {});
-    addMacroTest("Q_FALLTHROUGH( ) [[clang::fallthrough]]", {});
+    const auto addSpacedOperatorTest = [addTest](const QString& op) {
+        const auto tArg1 = QStringLiteral("x %1 y").arg(op);
+        const auto tArg2 = QStringLiteral("Foo<%1>").arg(tArg1);
+        for (const auto& templateArgument : {tArg1, tArg2}) {
+            addTest(QStringLiteral("spaced<%1>").arg(templateArgument), {templateArgument});
+        }
+    };
+
+    addSpacedOperatorTest("<");
+    addSpacedOperatorTest(">");
+    addSpacedOperatorTest("<=");
+    addSpacedOperatorTest(">=");
+    addSpacedOperatorTest("<<");
+    addSpacedOperatorTest(">>");
+    addSpacedOperatorTest("<<=");
+    addSpacedOperatorTest(">>=");
+    addSpacedOperatorTest("<=>");
+
+    addSpacedOperatorTest("->");
+    // -> must be recognized even when not surrounded with spaces
+    addTest("arrow<u->v>", {"u->v"});
+    addTest("arrow<Foo<u->v>>", {"Foo<u->v>"});
+
+    addTest("X::Y<Z>", {}, 1);
+    addTest("X<Z::C>", {"Z::C"});
+
+    addMacroTest("Q_UNIMPLEMENTED() qWarning(\"Unimplemented code.\")", {}, std::strlen("Q_UNIMPLEMENTED()"));
+    addMacroTest("Q_FALLTHROUGH( ) [[clang::fallthrough]]", {}, std::strlen("Q_FALLTHROUGH( )"));
     addMacroTest("( /*a)b*/ x , /*,*/y,z )", {"/*a)b*/ x", "/*,*/y", "z"});
 }
 
@@ -203,6 +251,7 @@ void TestStringHelpers::testParamIterator()
     QFETCH(QString, parens);
     QFETCH(QString, source);
     QFETCH(QStringList, params);
+    QFETCH(int, endPosition);
 
     auto it = KDevelop::ParamIterator(parens, source);
 
@@ -222,4 +271,5 @@ void TestStringHelpers::testParamIterator()
     }
 
     QVERIFY(!it);
+    QCOMPARE(it.position(), endPosition);
 }
