@@ -1,24 +1,12 @@
 /*
-    Copyright David Nolden  <david.nolden.kdevelop@art-master.de>
-    Copyright 2010 Milian Wolff <mail@milianw.de>
+    SPDX-FileCopyrightText: David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2010 Milian Wolff <mail@milianw.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "workingsetwidget.h"
-#include "debug.h"
+#include "debug_workingset.h"
 
 #include <sublime/area.h>
 
@@ -49,7 +37,7 @@ WorkingSetWidget::WorkingSetWidget(Sublime::Area* area, QWidget* parent)
 
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Ignored));
 
-    changingWorkingSet(m_area, QString(), area->workingSet());
+    changingWorkingSet(m_area, nullptr, QString(), area->workingSet());
 }
 
 void WorkingSetWidget::setVisible( bool visible )
@@ -60,9 +48,9 @@ void WorkingSetWidget::setVisible( bool visible )
     QWidget::setVisible( visible && (workingSet() && !workingSet()->isEmpty()) );
 }
 
-void WorkingSetWidget::changingWorkingSet( Sublime::Area* area, const QString& /*from*/, const QString& newSet)
+void WorkingSetWidget::changingWorkingSet(Sublime::Area* area, Sublime::Area* /*oldArea*/, const QString& /*from*/, const QString& newSet)
 {
-    qCDebug(SHELL) << "re-creating widget" << m_area;
+    qCDebug(WORKINGSET) << "re-creating widget" << m_area;
 
     Q_ASSERT(area == m_area);
     Q_UNUSED(area);
