@@ -117,6 +117,49 @@ QString htmlToPlainText(const QString& s, HtmlToPlainTextMode mode)
     }
     return QString();     // never reached
 }
+
+QByteArray escapeJavaScriptString(const QByteArray& str)
+{
+    // The special symbols that have to be escaped are listed e.g. here:
+    // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String#escape_sequences
+    QByteArray result;
+    result.reserve(str.size());
+
+    for (char ch : str) {
+        switch (ch) {
+        case '\n':
+            result += "\\n";
+            break;
+        case '\r':
+            result += "\\r";
+            break;
+        case '\t':
+            result += "\\t";
+            break;
+        case '\b':
+            result += "\\b";
+            break;
+        case '\f':
+            result += "\\f";
+            break;
+        case '\v':
+            result += "\\v";
+            break;
+        case '\0':
+            result += "\\0";
+            break;
+        case '\'':
+        case '"':
+        case '\\':
+            result += '\\';
+            [[fallthrough]];
+        default:
+            result += ch;
+        }
+    }
+
+    return result;
+}
 }
 
 int KDevelop::findAsciiIdentifierLength(const QStringRef& str)
