@@ -6,7 +6,6 @@
 */
 
 #include "cmakemanager.h"
-#include "cmakeedit.h"
 #include "cmakeutils.h"
 #include "cmakeprojectdata.h"
 #include "duchain/cmakeparsejob.h"
@@ -198,16 +197,17 @@ private:
     void tryDirectImport()
     {
         auto* importJob = new CMake::FileApi::ImportJob(project, this);
+        importJob->setInvalidateOutdatedData();
+        importJob->setEmitInvalidData();
         connect(importJob, &CMake::FileApi::ImportJob::dataAvailable, this, [this](const CMakeProjectData& data) {
-            if (!data.compilationData.isValid || data.lastModifiedCMakeFile > data.lastModifiedProjectData) {
-                qCDebug(CMAKE) << "reconfigure, project data is outdated" << data.lastModifiedCMakeFile
-                               << data.lastModifiedProjectData;
-
+            if (!data.compilationData.isValid) {
+                qCDebug(CMAKE) << "reconfiguring project" << project->name() << "because project data is outdated";
                 reconfigureThenImport();
             } else {
-                qCDebug(CMAKE) << "skip configure, project data is up to date" << data.lastModifiedCMakeFile
-                               << data.lastModifiedProjectData;
-
+                Q_ASSERT_X(!data.isOutdated, Q_FUNC_INFO,
+                           "ImportJob::setInvalidateOutdatedData() failed to mark outdated data invalid.");
+                qCDebug(CMAKE) << "skipping configure project" << project->name()
+                               << "because project data is up to date";
                 fileImportDone(data);
             }
         });
@@ -216,11 +216,8 @@ private:
 
     void fileImportDone(const CMakeProjectData& data)
     {
-        if (!data.compilationData.isValid) {
-            tryCMakeServer();
-        } else {
-            manager->integrateData(data, project);
-        }
+        Q_ASSERT(data.compilationData.isValid);
+        manager->integrateData(data, project);
     }
 
     QSharedPointer<CMakeServer> server;
@@ -233,12 +230,14 @@ KJob* CMakeManager::createImportJob(ProjectFolderItem* item, bool forceConfigure
 {
     auto project = item->project();
 
+    delete m_configureStatusMessages.value(project); // discard now-obsolete message from the previous configuration
+
     auto job = new ChooseCMakeInterfaceJob(project, this, forceConfigure);
     connect(job, &KJob::result, this, [this, job, project]() {
         if (job->error() != 0) {
             qCWarning(CMAKE) << "couldn't load project successfully" << project->name() << job->error()
                              << job->errorText();
-            showConfigureErrorMessage(project->name(), job->errorText());
+            showConfigureErrorMessage(*project, job->errorString());
         }
     });
 
@@ -272,6 +271,9 @@ QList<KDevelop::ProjectTargetItem*> CMakeManager::targets() const
 CMakeFile CMakeManager::fileInformation(KDevelop::ProjectBaseItem* item) const
 {
     const auto& data = m_projects[item->project()].data.compilationData;
+    if (!data.isValid) {
+        return {};
+    }
 
     auto toCanonicalPath = [](const Path &path) -> Path {
         // if the path contains a symlink, then we will not find it in the lookup table
@@ -357,8 +359,10 @@ bool CMakeManager::reload(KDevelop::ProjectFolderItem* folder)
     qCDebug(CMAKE) << "reloading" << folder->path();
 
     IProject* project = folder->project();
-    if (!project->isReady())
+    if (!project->isReady()) {
+        qCDebug(CMAKE) << "the project is being reloaded, aborting reload!";
         return false;
+    }
 
     KJob* job = createImportJob(folder, true);
     project->setReloadJob(job);
@@ -485,6 +489,14 @@ static void cleanupTestSuites(const QVector<CTestSuite*>& testSuites, const QVec
 
 void CMakeManager::integrateData(const CMakeProjectData &data, KDevelop::IProject* project, const QSharedPointer<CMakeServer>& server)
 {
+    // TODO: show the warning message only after the entire import job finishes. When the message
+    // is shown here (earlier), the user can follow the advice and manage to reload the project
+    // before the current import finishes. Then KDevelop would print a kdevelop.plugins.cmake.debug
+    // message "the project is being reloaded, aborting reload!" and ignore the reload request.
+    if (data.isOutdated) {
+        showConfigureOutdatedMessage(*project);
+    }
+
     if (server) {
         connect(server.data(), &CMakeServer::response, project, [this, project](const QJsonObject& response) {
             if (response[QStringLiteral("type")] == QLatin1String("signal")) {
@@ -493,7 +505,7 @@ void CMakeManager::integrateData(const CMakeProjectData &data, KDevelop::IProjec
                 } else
                     qCDebug(CMAKE) << "unhandled signal response..." << project << response;
             } else if (response[QStringLiteral("type")] == QLatin1String("error")) {
-                showConfigureErrorMessage(project->name(), response[QStringLiteral("errorMessage")].toString());
+                showConfigureErrorMessage(*project, response[QStringLiteral("errorMessage")].toString());
             } else if (response[QStringLiteral("type")] == QLatin1String("reply")) {
                 const auto inReplyTo = response[QStringLiteral("inReplyTo")];
                 if (inReplyTo == QLatin1String("configure")) {
@@ -519,10 +531,8 @@ void CMakeManager::integrateData(const CMakeProjectData &data, KDevelop::IProjec
             reload(project->projectItem());
         });
         connect(projectWatcher(project), &KDirWatch::dirty, reloadTimer, [this, project, reloadTimer](const QString &strPath) {
-            const auto& cmakeFiles = m_projects[project].data.cmakeFiles;
-            KDevelop::Path path(strPath);
-            auto it = cmakeFiles.find(path);
-            if (it == cmakeFiles.end() || it->isGenerated || it->isExternal) {
+            const auto it = m_projects.constFind(project);
+            if (it == m_projects.cend() || !it->data.cmakeFiles.contains(Path{strPath})) {
                 return;
             }
             qCDebug(CMAKE) << "eventually starting reload due to change of" << strPath;
@@ -634,12 +644,19 @@ KTextEditor::Range CMakeManager::termRangeAtPosition(const KTextEditor::Document
     return KTextEditor::Range(start, end);
 }
 
-void CMakeManager::showConfigureErrorMessage(const QString& projectName, const QString& errorMessage) const
+void CMakeManager::showConfigureOutdatedMessage(const KDevelop::IProject& project)
+{
+    const QString messageText = i18n(
+        "Configured project '%1' with outdated CMake data."
+        " As a result, KDevelop's code understanding may be wrong.\n"
+        "\n"
+        "To fix this issue, please right-click the project item in the projects tool view and click 'Reload'.",
+        project.name());
+    showConfigureStatusMessage(project, messageText, Sublime::Message::Warning);
+}
+
+void CMakeManager::showConfigureErrorMessage(const IProject& project, const QString& errorMessage)
 {
-    if (!QApplication::activeWindow()) {
-        // Do not show a message box if there is no active window in order not to block unit tests.
-        return;
-    }
     const QString messageText = i18n(
         "Failed to configure project '%1' (error message: %2)."
         " As a result, KDevelop's code understanding will likely be broken.\n"
@@ -647,8 +664,16 @@ void CMakeManager::showConfigureErrorMessage(const QString& projectName, const Q
         "To fix this issue, please ensure that the project's CMakeLists.txt files"
         " are correct, and KDevelop is configured to use the correct CMake version and settings."
         " Then right-click the project item in the projects tool view and click 'Reload'.",
-        projectName, errorMessage);
-    auto* message = new Sublime::Message(messageText, Sublime::Message::Error);
+        project.name(), errorMessage);
+    showConfigureStatusMessage(project, messageText, Sublime::Message::Error);
+}
+
+void CMakeManager::showConfigureStatusMessage(const IProject& project, const QString& messageText,
+                                              Sublime::Message::MessageType messageType)
+{
+    auto& message = m_configureStatusMessages[&project];
+    Q_ASSERT_X(!message, Q_FUNC_INFO, "The previous message must have been discarded earlier.");
+    message = new Sublime::Message(messageText, messageType);
     ICore::self()->uiController()->postMessage(message);
 }
 
@@ -697,11 +722,13 @@ QPair<QString, QString> CMakeManager::cacheValue(KDevelop::IProject* /*project*/
 
 void CMakeManager::projectClosing(IProject* p)
 {
-    auto it = m_projects.find(p);
-    if (it != m_projects.end()) {
+    const auto it = m_projects.constFind(p);
+    if (it != m_projects.cend()) {
         cleanupTestSuites(it->testSuites, it->testSuiteJobs);
         m_projects.erase(it);
     }
+
+    delete m_configureStatusMessages.take(p); // discard the message, because closing its project obsoletes it
 }
 
 ProjectFilterManager* CMakeManager::filterManager() const
