@@ -20,31 +20,66 @@
 #include <interfaces/ilaunchconfiguration.h>
 #include <interfaces/iuicontroller.h>
 #include <outputview/outputmodel.h>
+#include <util/scopeddialog.h>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KParts/MainWindow>
 
 #include <QFileInfo>
-#include <QPointer>
 
 using namespace KDevMI;
 using namespace KDevelop;
 
+template<class JobBase>
+MIDebugJobBase<JobBase>::MIDebugJobBase(MIDebuggerPlugin* plugin, QObject* parent)
+    : JobBase(parent)
+{
+    Q_ASSERT(plugin);
+
+    JobBase::setCapabilities(KJob::Killable);
+
+    m_session = plugin->createSession();
+    QObject::connect(m_session, &MIDebugSession::finished, this, &MIDebugJobBase::done);
+
+    qCDebug(DEBUGGERCOMMON) << "created debug job" << this << "with" << m_session;
+}
+
+template<class JobBase>
+MIDebugJobBase<JobBase>::~MIDebugJobBase()
+{
+    // Don't print m_session unconditionally, because it can be already destroyed if this job is finished.
+    qCDebug(DEBUGGERCOMMON) << "destroying debug job" << this;
+    if (!JobBase::isFinished()) {
+        qCDebug(DEBUGGERCOMMON) << "debug job destroyed before it finished, stopping debugger of" << m_session;
+        m_session->stopDebugger();
+    }
+}
+
+template<typename JobBase>
+void MIDebugJobBase<JobBase>::done()
+{
+    qCDebug(DEBUGGERCOMMON) << "finishing debug job" << this << "with" << m_session;
+    JobBase::emitResult();
+}
+
+template<typename JobBase>
+bool MIDebugJobBase<JobBase>::doKill()
+{
+    qCDebug(DEBUGGERCOMMON) << "killing debug job" << this << "and stopping debugger of" << m_session;
+    m_session->stopDebugger();
+    return true;
+}
+
 MIDebugJob::MIDebugJob(MIDebuggerPlugin* p, ILaunchConfiguration* launchcfg,
                    IExecutePlugin* execute, QObject* parent)
-    : KDevelop::OutputJob(parent)
+    : MIDebugJobBase(p, parent)
     , m_launchcfg(launchcfg)
     , m_execute(execute)
 {
-    setCapabilities(Killable);
-
-    m_session = p->createSession();
     connect(m_session, &MIDebugSession::inferiorStdoutLines, this, &MIDebugJob::stdoutReceived);
     connect(m_session, &MIDebugSession::inferiorStderrLines, this, &MIDebugJob::stderrReceived);
 
-    connect(m_session, &MIDebugSession::finished, this, &MIDebugJob::done);
-
     if (launchcfg->project()) {
         setObjectName(i18nc("ProjectName: run configuration name", "%1: %2",
                             launchcfg->project()->name(), launchcfg->name()));
@@ -62,24 +97,18 @@ void MIDebugJob::start()
     // check if the config is valid
     QString executable = m_execute->executable(m_launchcfg, err).toLocalFile();
     if (!err.isEmpty()) {
-        setError(-1);
-        setErrorText(err);
-        emitResult();
+        finishWithError(InvalidExecutable, err);
         return;
     }
 
     if (!QFileInfo(executable).isExecutable()) {
-        setError(-1);
-        setErrorText(i18n("'%1' is not an executable", executable));
-        emitResult();
+        finishWithError(ExecutableIsNotExecutable, i18n("'%1' is not an executable", executable));
         return;
     }
 
     QStringList arguments = m_execute->arguments(m_launchcfg, err);
     if (!err.isEmpty()) {
-        setError(-1);
-        setErrorText(err);
-        emitResult();
+        finishWithError(InvalidArguments, err);
         return;
     }
 
@@ -106,12 +135,6 @@ void MIDebugJob::start()
     }
 }
 
-bool MIDebugJob::doKill()
-{
-    m_session->stopDebugger();
-    return true;
-}
-
 void MIDebugJob::stderrReceived(const QStringList& l)
 {
     if (OutputModel* m = model()) {
@@ -126,62 +149,46 @@ void MIDebugJob::stdoutReceived(const QStringList& l)
     }
 }
 
+void MIDebugJob::finishWithError(int errorCode, const QString& errorText)
+{
+    qCDebug(DEBUGGERCOMMON) << "failing" << this << "and stopping debugger of" << m_session;
+    m_session->stopDebugger();
+    setError(errorCode);
+    setErrorText(errorText);
+    emitResult();
+}
+
 OutputModel* MIDebugJob::model()
 {
     return qobject_cast<OutputModel*>(OutputJob::model());
 }
 
-void MIDebugJob::done()
-{
-    emitResult();
-}
-
 MIExamineCoreJob::MIExamineCoreJob(MIDebuggerPlugin *plugin, QObject *parent)
-    : KJob(parent)
+    : MIDebugJobBase(plugin, parent)
 {
-    setCapabilities(Killable);
-
-    m_session = plugin->createSession();
-    connect(m_session, &MIDebugSession::finished, this, &MIExamineCoreJob::done);
-
     setObjectName(i18n("Debug core file"));
 }
 
 void MIExamineCoreJob::start()
 {
-    QPointer<SelectCoreDialog> dlg = new SelectCoreDialog(ICore::self()->uiController()->activeMainWindow());
+    ScopedDialog<SelectCoreDialog> dlg(ICore::self()->uiController()->activeMainWindow());
     if (dlg->exec() == QDialog::Rejected) {
+        qCDebug(DEBUGGERCOMMON) << "Select Core File dialog rejected, finishing" << this << "and stopping debugger of"
+                                << m_session;
+        m_session->stopDebugger();
         done();
-        delete dlg;
         return;
     }
 
     if (!m_session->examineCoreFile(dlg->executableFile(), dlg->core())) {
         done();
     }
-    delete dlg;
-}
-
-bool MIExamineCoreJob::doKill()
-{
-    m_session->stopDebugger();
-    return true;
-}
-
-void MIExamineCoreJob::done()
-{
-    emitResult();
 }
 
 MIAttachProcessJob::MIAttachProcessJob(MIDebuggerPlugin *plugin, int pid, QObject *parent)
-    : KJob(parent)
+    : MIDebugJobBase(plugin, parent)
     , m_pid(pid)
 {
-    setCapabilities(Killable);
-
-    m_session = plugin->createSession();
-    connect(m_session, &MIDebugSession::finished, this, &MIAttachProcessJob::done);
-
     setObjectName(i18n("Debug process %1", pid));
 }
 
@@ -191,14 +198,3 @@ void MIAttachProcessJob::start()
         done();
     }
 }
-
-bool MIAttachProcessJob::doKill()
-{
-    m_session->stopDebugger();
-    return true;
-}
-
-void MIAttachProcessJob::done()
-{
-    emitResult();
-}
